unit UScroll;

// DATE:     February 1999
// CATEGORY: Realtime Charting
// PROBLEM:  I acquire data from a sensor. I would like to display
//           only last one minute of data. How can I achive this?
// VERSION:  Delphi3 and Delphi4


interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ExtCtrls, TeEngine, Series, TeeProcs, Chart, StdCtrls;

type
  TForm1 = class(TForm)
    Chart1: TChart;
    Series1: TFastLineSeries;
    Timer1: TTimer;
    Panel1: TPanel;
    RadioGroup1: TRadioGroup;
    procedure Series1AfterAdd(Sender: TChartSeries; ValueIndex: Integer);
    procedure Timer1Timer(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure RadioGroup1Click(Sender: TObject);
  private
    tmp       :Double;
    step      :Double;
    { Private declarations }
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.DFM}


//---------------------------------------------------
{After we've added new point, we delete all unnecessary points
and recalibrate horizontal axis to show only newest data}
procedure TForm1.Series1AfterAdd(Sender: TChartSeries;
  ValueIndex: Integer);
begin
     With Sender.GetHorizAxis do  { <-- with the Horizontal Axis... }
     Begin
      Automatic := False;
      //always show the last time
      Maximum := Sender.XValues.MaxValue;
      // show only last desired interval
      Minimum := Maximum - step;
     end;

     // Delete all "invisible" points
     While (Sender.Count>0) and
      (Sender.XValues[0] < Sender.GetHorizAxis.Minimum) do
      Sender.Delete(0);


end;
//---------------------------------------------------

//---------------------------------------------------
{This event supplies data for Series1}
procedure TForm1.Timer1Timer(Sender: TObject);
begin
     tmp:=tmp+Random(1000)-500;
     Series1.AddXY(Now,tmp);
end;

//---------------------------------------------------
procedure TForm1.FormCreate(Sender: TObject);
begin
     //Initial setup for Series and Chart
     Series1.XValues.Order:=loAscending;
     Series1.XValues.DateTime:=true;
     Series1.GetHorizAxis.Increment:=DateTimeStep[dtOneSecond];
     Series1.GetHorizAxis.DateTimeFormat:='hh:mm:ss';
     Series1.GetHorizAxis.LabelsMultiLine:=false;
     Chart1.BufferedDisplay:=True; // for speedup
     Randomize;
     tmp:=Random(1000);
     RadioGroup1Click(Self);
     Timer1.Enabled:=true;

end;
//---------------------------------------------------

//---------------------------------------------------
{Choose the time limit for display}
procedure TForm1.RadioGroup1Click(Sender: TObject);
begin
     //disable data aquisition
     Timer1.Enabled:=false;
     Case RadioGroup1.ItemIndex of
       0: step:=DateTimeStep[dtOneMinute];
       1: step:=DateTimeStep[dtFiveMinutes];
       2: step:=DateTimeStep[dtOneHour];
       3: step:=DateTimeStep[dtTwoHours];
       4: step:=DateTimeStep[dtTwelveHours];
       5: step:=DateTimeStep[dtOneDay];
     end;
     //enable data aquisition
     Timer1.Enabled:=true;
end;
//---------------------------------------------------

end.
